<?php
/**
 * Plugin Name: WP Mobile Menu
 * Plugin URI: https://ietheme.com/portfolio/mobile-menu/
 * Description: WP Mobile Menu allows you to add a bottom menu for responsive device.
 * Version: 1.0.1
 * Author: 99839
 * Author URI: https://ietheme.com
 * License: GPL v2 or later
 * License URI: https://www.gnu.org/licenses/gpl-2.0.html
 * Text Domain: ie-mobile-menu
 * Domain Path: /languages
*/

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

define( 'WP_MOBILE_MENU_VERSION', '1.0.1' );
define( 'WP_MOBILE_MENU_DIR_URL', plugin_dir_url( __FILE__ ) );
define( 'WP_MOBILE_MENU_DIR_PATH', plugin_dir_path( __FILE__ ) );


if ( class_exists( 'WPmobileMenu' ) ){
    $wpmobilemenu = new WPmobileMenu;
}

class WPmobileMenu{

    public function __construct() {
        $this->includes();
        $this->_hooks();
    }

    function _hooks(){
        add_action( 'wp_enqueue_scripts', array( $this, 'add_theme_scripts' ) );
        add_action( 'wp_footer', array($this, 'wp_bottom_menu' ) );
        add_action( 'customize_register', array($this, 'wp_bottom_menu_customize_register' ) );
        add_action( 'wp_footer', array($this, 'wpmobilemenu_customize_css') );
        add_filter( 'plugin_action_links', array($this, 'wp_bottom_menu_action_links'), 10, 2 );
    } 
    
    function includes(){
        require_once(WP_MOBILE_MENU_DIR_PATH.'inc/functions.php');
    }

    // enqueue scripts
    function add_theme_scripts() {
        wp_enqueue_style( 'ie-mobile-menu-style', WP_MOBILE_MENU_DIR_URL . 'assets/css/style.css', array(), WP_MOBILE_MENU_VERSION, 'all');
        wp_enqueue_script( 'ie-mobile-menu-js', WP_MOBILE_MENU_DIR_URL . 'assets/js/main.js', array(), WP_MOBILE_MENU_VERSION, true);
        if(!get_option( 'wpmobilemenu_disable_fontawesome', false )){
        wp_enqueue_style( 'font-awesome', WP_MOBILE_MENU_DIR_URL . 'assets/css/font-awesome.min.css', array(), CUSTOMIZER_REPEATER_VERSION );
        }
    }

    // wp bottom menu
    function wp_bottom_menu() {
        ?>
        <div class="ie-mobile-menu">

        <?php
        $customizer_repeater_wpbm = get_option('customizer_repeater_wpbm', json_encode( array(
            array("choice" => "wpbm-homepage" ,"subtitle" => "fa-home", "title" => "Home", "id" => "customizer_repeater_1" ),
            array("choice" => "wpbm-user-account" ,"subtitle" => "fa-user", "title" => "Account", "id" => "customizer_repeater_2" ),
            array("choice" => "wpbm-woo-cart" ,"subtitle" => "fa-shopping-cart", "title" => "Cart", "id" => "customizer_repeater_3" ),
            array("choice" => "wpbm-woo-search" ,"subtitle" => "fa-search", "title" => "Search", "id" => "customizer_repeater_4" ),
        ) ) );
        /*This returns a json so we have to decode it*/

        $customizer_repeater_wpbm_decoded = json_decode($customizer_repeater_wpbm);
        $wpbmsf;
        foreach($customizer_repeater_wpbm_decoded as $repeater_item){

            if($repeater_item->choice == "wpbm-woo-search" or $repeater_item->choice == "wpbm-post-search"):?>
                <a onclick="wpbmsft()" class="ie-mobile-menu-item ie-mobile-menu-search-form-trigger">
            <?php else: ?>
                <a href="<?php 
                    switch($repeater_item->choice){
                        case "wpbm-homepage":
                            echo esc_url( home_url() );
                        break;
                        case "wpbm-woo-cart":
                            if ( class_exists( 'WooCommerce' ) ) {
								echo esc_url( wc_get_page_permalink( 'cart' ) );
							} else {
                                echo '#';
							}   
                        break;
                        case "wpbm-user-account":
                            if ( class_exists( 'WooCommerce' ) ) {
								echo esc_url( wc_get_page_permalink( 'myaccount' ) );
							} else {
                                //echo '#';
                                if ( is_user_logged_in() ) {
                                    echo esc_attr_e( get_edit_profile_url() );   
                                } else {
                                    echo esc_url( wp_login_url( get_permalink() ) );
                                }
							}  
                        break;
        
                        default:
                            echo esc_url( $repeater_item->link );
                    }
                ?>" class="ie-mobile-menu-item">
            <?php endif; ?>
                    <i class="ie-mobile-menu-item-icons fa <?php echo $repeater_item->subtitle; ?>"></i>
                    <?php if(!get_option( 'wpmobilemenu_disable_title', false )): ?>
                    <span><?php echo $repeater_item->title; ?></span>
                    <?php endif; ?>
                </a>
            <?php
            $wpbmsf = $repeater_item->choice;           

        }
        ?>
    </div>

    <div class="ie-mobile-menu-search-form-wrapper">
    <form role="search" method="get" action="<?php echo esc_url( home_url( '/'  ) ); ?>" class="ie-mobile-menu-search-form">
        <svg class="svg-icon" aria-hidden="true" role="img" focusable="false" xmlns="http://www.w3.org/2000/svg" width="23" height="23" viewBox="0 0 23 23"><path d="M38.710696,48.0601792 L43,52.3494831 L41.3494831,54 L37.0601792,49.710696 C35.2632422,51.1481185 32.9839107,52.0076499 30.5038249,52.0076499 C24.7027226,52.0076499 20,47.3049272 20,41.5038249 C20,35.7027226 24.7027226,31 30.5038249,31 C36.3049272,31 41.0076499,35.7027226 41.0076499,41.5038249 C41.0076499,43.9839107 40.1481185,46.2632422 38.710696,48.0601792 Z M36.3875844,47.1716785 C37.8030221,45.7026647 38.6734666,43.7048964 38.6734666,41.5038249 C38.6734666,36.9918565 35.0157934,33.3341833 30.5038249,33.3341833 C25.9918565,33.3341833 22.3341833,36.9918565 22.3341833,41.5038249 C22.3341833,46.0157934 25.9918565,49.6734666 30.5038249,49.6734666 C32.7048964,49.6734666 34.7026647,48.8030221 36.1716785,47.3875844 C36.2023931,47.347638 36.2360451,47.3092237 36.2726343,47.2726343 C36.3092237,47.2360451 36.347638,47.2023931 36.3875844,47.1716785 Z" transform="translate(-20 -31)" /></svg>
	    <input type="hidden" name="post_type" value="<?php if($wpbmsf=="wpbm-woo-search" and class_exists( 'ie-mobile-menu' )) echo esc_attr("product"); else echo esc_attr("post"); ?>" />
        <input type="search" class="search-field" placeholder="<?php echo esc_attr_x( 'Search &hellip;', 'placeholder', 'ie-mobile-menue' ); ?>" value="<?php echo get_search_query(); ?>" name="s" title="<?php echo esc_attr_x( 'Search for:', 'label', 'ie-mobile-menu' ); ?>" />
    </form>
    </div><?php       
        
    } 
    // customizer api
    function wp_bottom_menu_customize_register( $wp_customize ) {
                
        // Add Theme Options Panel.
        $wp_customize->add_panel( 'wpmobilemenu_panel',
            array(
                'title'      => esc_html__( 'Mobile Menu', 'ie-mobile-menu' ),
                'priority'   => 201
            )
        );

        // Section: Settings

        $wp_customize->add_section( 'wpmobilemenu_section_settings', array(
            'title'      => esc_html__( 'Settings', 'ie-mobile-menu' ),
            'priority'   => 120,
            'panel'      => 'wpmobilemenu_panel', 
        ));

                $wp_customize->add_setting( 'wpmobilemenu_display_px' , array(
                    'default'     => '1024',
                    'type'        => 'option',
                ));
                
                $wp_customize->add_control('wpmobilemenu_display_px', array(
                    'label'    => __( 'Active The Menu (px)', 'ie-mobile-menu' ), 
                    'section'  => 'wpmobilemenu_section_settings',
                    'settings' => 'wpmobilemenu_display_px',
                    'type' => 'number',
                ));
                
                $wp_customize->add_setting( 'wpmobilemenu_display_always' , array(
                    'default'     => false,
                    'type'        => 'option',
                ));
                
                $wp_customize->add_control('wpmobilemenu_display_always', array(
                    'label'    => __( 'Active for any screen size?', 'ie-mobile-menu' ), 
                    'section'  => 'wpmobilemenu_section_settings',
                    'settings' => 'wpmobilemenu_display_always',
                    'type' => 'checkbox',
                ));
                
                $wp_customize->add_setting( 'wpmobilemenu_zindex' , array(
                    'default'     => '9999',
                    'type'        => 'option',
                ));
                
                $wp_customize->add_control('wpmobilemenu_zindex', array(
                    'label'    => __( 'Menu Z-Index', 'ie-mobile-menu' ), 
                    'description' => esc_html__( 'Recommended value: 9999', 'ie-mobile-menu' ),
                    'section'  => 'wpmobilemenu_section_settings',
                    'settings' => 'wpmobilemenu_zindex',
                    'type' => 'number',
                ));

                $wp_customize->add_setting( 'wpmobilemenu_fontsize' , array(
                    'default'     => '12',
                    'type'        => 'option',
                ));
                
                $wp_customize->add_control( 'wpmobilemenu_fontsize', array(
                    'label'    => __( 'Menu Font Size (px)', 'ie-mobile-menu' ), 
                    'section'  => 'wpmobilemenu_section_settings',
                    'settings' => 'wpmobilemenu_fontsize',
                    'type' => 'number',
                ));

                $wp_customize->add_setting( 'wpmobilemenu_iconsize' , array(
                    'default'     => '24',
                    'type'        => 'option',
                ));
                
                $wp_customize->add_control( 'wpmobilemenu_iconsize', array(
                    'label'    => __( 'Menu Icon Size (px)', 'ie-mobile-menu' ), 
                    'section'  => 'wpmobilemenu_section_settings',
                    'settings' => 'wpmobilemenu_iconsize',
                    'type' => 'number',
                ));

                $wp_customize->add_setting( 'wpmobilemenu_iconcolor', array(
                    'default' => '#000000',
                    'section'  => 'wpmobilemenu_section_settings',
                    'sanitize_callback' => 'sanitize_hex_color',
                    'type' => 'option'
                ));

                $wp_customize->add_setting( 'wpmobilemenu_textcolor', array(
                    'default' => '#000000',
                    'section'  => 'wpmobilemenu_section_settings',
                    'sanitize_callback' => 'sanitize_hex_color',
                    'type' => 'option'
                ));

                $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'wpmobilemenu_textcolor', array(
                    'label'    => __( 'Menu Text Color', 'ie-mobile-menu' ), 
                    'section'  => 'wpmobilemenu_section_settings',
                )));   

                 $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'wpmobilemenu_iconcolor', array(
                    'label'    => __( 'Menu Icon Color', 'ie-mobile-menu' ), 
                    'section'  => 'wpmobilemenu_section_settings',
                )));

                $wp_customize->add_setting( 'wpmobilemenu_bgcolor', array(
                    'default' => '#ffffff',
                    'section'  => 'wpmobilemenu_section_settings',
                    'sanitize_callback' => 'sanitize_hex_color',
                    'type' => 'option'
                ));

                $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'wpmobilemenu_bgcolor', array(
                    'label'    => __( 'Menu Background Color', 'ie-mobile-menu' ), 
                    'section'  => 'wpmobilemenu_section_settings',
                )));

                $wp_customize->add_setting( 'wpmobilemenu_disable_title' , array(
                    'default'     => false,
                    'type'        => 'option',
                ));
                
                $wp_customize->add_control('wpmobilemenu_disable_title', array(
                    'label'    => __( 'Disable title?', 'ie-mobile-menu' ), 
                    'section'  => 'wpmobilemenu_section_settings',
                    'settings' => 'wpmobilemenu_disable_title',
                    'type' => 'checkbox',
                ));

        // Section: Menu Items
        
        $wp_customize->add_section('wpmobilemenu_section_menuitems', array(
            'title' => __('Menu Items', 'ie-mobile-menu'),
            'priority' => 140,
            'panel'      => 'wpmobilemenu_panel' 
        ));

                $wp_customize->add_setting( 'customizer_repeater_wpbm', array(
                    'sanitize_callback' => 'customizer_repeater_sanitize',
                    'type' => 'option',
                    'default' => json_encode( array(
                       array("choice" => "wpbm-homepage" ,"subtitle" => "fa-home", "title" => "Home", "id" => "customizer_repeater_1" ),
                       array("choice" => "wpbm-user-account" ,"subtitle" => "fa-user", "title" => "Account", "id" => "customizer_repeater_2" ),
                       array("choice" => "wpbm-woo-cart" ,"subtitle" => "fa-shopping-cart", "title" => "Cart", "id" => "customizer_repeater_3" ),
                       array("choice" => "wpbm-woo-search" ,"subtitle" => "fa-search", "title" => "Search", "id" => "customizer_repeater_4" ),
                       ))
                ));

                $wp_customize->add_control( new Customizer_Repeater( $wp_customize, 'customizer_repeater_wpbm', array(
                    'label'   => esc_html__('Menu Item','ie-mobile-menu'),
                    'section' => 'wpmobilemenu_section_menuitems',
                    'customizer_repeater_title_control' => true,
                    'customizer_repeater_link_control' => true,
                    'customizer_repeater_subtitle_control' => true,
                )));

                $wp_customize->add_setting( 'wpmobilemenu_howuseicon' , array(
                    'type'        => 'option',
                ));
                
                $wp_customize->add_control( 'wpmobilemenu_howuseicon', array(
                    'label'    => __( 'How to use the Icons?', 'ie-mobile-menu' ), 
                    'description' => sprintf(
                        __( 'Add the names from (%1$s) to the icon field.<br>Example:<code>fa-home</code>', 'ie-mobile-menu' ),
                        sprintf( '<a target="_blank" href="https://fontawesome.com/v4.7.0/icons/" rel="nofollow">%s</a>', esc_html__( 'FontAwesome', 'ie-mobile-menu' ) )
                    ),
                    'section'  => 'wpmobilemenu_section_menuitems',
                    'settings' => 'wpmobilemenu_howuseicon',
                    'type' => 'hidden',
                ));

                $wp_customize->add_setting( 'wpmobilemenu_disableicon' , array(
                    'type'        => 'option',
                ));
                
                $wp_customize->add_control( 'wpmobilemenu_disableicon', array(
                    'label'    => __( 'Why disable FontAwesome Icons?', 'ie-mobile-menu' ), 
                    'description' => sprintf(
                        __( 'If you theme already load FontAwesome or use other icon, You don\'t need load them  any more. How to use other icons, see more at %1$s.', 'ie-mobile-menu' ),
                        sprintf( '<a target="_blank" href="https://ietheme.com/portfolio/mobile-menu.html" rel="nofollow">%s</a>', esc_html__( 'here', 'ie-mobile-menu' ) )
                    ),
                    'section'  => 'wpmobilemenu_section_menuitems',
                    'settings' => 'wpmobilemenu_disableicon',
                    'type' => 'hidden',
                ));                

                $wp_customize->add_setting( 'wpmobilemenu_disable_fontawesome' , array(
                    'default'     => false,
                    'type'        => 'option',
                ));
                
                $wp_customize->add_control('wpmobilemenu_disable_fontawesome', array(
                    'label'    => __( 'Disable FontAwesome?', 'ie-mobile-menu' ), 
                    'section'  => 'wpmobilemenu_section_menuitems',
                    'settings' => 'wpmobilemenu_disable_fontawesome',
                    'type' => 'checkbox',
                ));

    }

    // plugin action links
    function wp_bottom_menu_action_links( $links_array, $plugin_file_name ){
        if( strpos( $plugin_file_name, basename(__FILE__) ) ) {
            array_unshift( $links_array, '<a href="' . admin_url( 'customize.php?autofocus[panel]=wpmobilemenu_panel' ) . '">Settings</a>' );
        }
        return $links_array;
    }

    // customize css
    function wpmobilemenu_customize_css(){
        ?>
        <style type="text/css">
            <?php if (!get_option( 'wpmobilemenu_display_always', false )): ?>
                @media (max-width: <?php echo get_option( 'wpmobilemenu_display_px', '1024' ); ?>px){
                    .ie-mobile-menu{display:flex;}.ie-mobile-menu-search-form-wrapper{display: block;}body{padding-bottom: 70px;}
                }
            <?php else: ?>
                    .ie-mobile-menu{display:flex;}.ie-mobile-menu-search-form-wrapper{display: block;}body{padding-bottom: 70px;}
            <?php endif; ?>

            :root{
                --wpmobilemenu-font-size: <?php echo get_option( 'wpmobilemenu_fontsize', '12' );?>px;
                --wpmobilemenu-icon-size: <?php echo get_option( 'wpmobilemenu_iconsize', '24' );?>px;
                --wpmobilemenu-text-color: <?php echo get_option( 'wpmobilemenu_textcolor', '#000000' );?>;
                --wpmobilemenu-icon-color: <?php echo get_option( 'wpmobilemenu_iconcolor', '#000000' );?>;
                --wpmobilemenu-bgcolor: <?php echo get_option( 'wpmobilemenu_bgcolor', '#ffffff' );?>;
                --wpmobilemenu-zindex: <?php echo get_option( 'wpmobilemenu_zindex', '9999' ); ?>;;
            }

        </style>
        <?php
    }
    
} // class


function pluginprefix_activate() { 
    flush_rewrite_rules(); 
}
register_activation_hook( __FILE__, 'pluginprefix_activate' );

function pluginprefix_deactivate() {
	
    delete_option(' customizer_repeater_wpbm' );
    delete_option( 'wpmobilemenu_display_px' );
    delete_option( 'wpmobilemenu_display_always' );
    delete_option( 'wpmobilemenu_fontsize' );
    delete_option( 'wpmobilemenu_iconsize' );
    delete_option( 'wpmobilemenu_textcolor' );
    delete_option( 'wpmobilemenu_iconcolor' );
    delete_option( 'wpmobilemenu_bgcolor' );
    delete_option( 'wpmobilemenu_zindex' );
    delete_option( 'wpmobilemenu_disable_title' );
    delete_option( 'wpmobilemenu_disable_fontawesome' );
	
    flush_rewrite_rules();
}
register_deactivation_hook( __FILE__, 'pluginprefix_deactivate' );